@@ -18,7 +18,7 @@ use File::Path ();
 use Cwd ();
 use Config;
 
-our $VERSION = '0.293';
+our $VERSION = '0.294';
 
 use constant WIN32 => $^O eq 'MSWin32';
 
@@ -186,7 +186,7 @@ sub cmd_install {
     my $worker = App::cpm::Worker->new(
         verbose         => $self->{verbose},
         home            => $self->{home},
-        logger          => $self->{logger},
+        logger          => $logger,
         notest          => $self->{notest},
         sudo            => $self->{sudo},
         resolver        => $self->generate_resolver,
@@ -249,7 +249,7 @@ sub cleanup {
     my @file = map  { $_->[0] }
                grep { $_->[1] < $week }
                map  { [$_, (stat $_)[9]] }
-               glob "$self->{home}/build*.log";
+               glob "$self->{home}/build.log.*";
     unlink $_ for @file;
 }
 
@@ -480,7 +480,7 @@ To merge cpm into cpanm, there are several TODOs:
 
 =item * (DONE) Win32? - support platforms that do not have fork(2) system call
 
-=item * Logging? - the parallel feature makes log really messy
+=item * (DONE) Logging? - the parallel feature makes log really messy
 
 =back
 
