@@ -1,7 +1,7 @@
 package App::cpm::Resolver::Cascade;
 use strict;
 use warnings;
-our $VERSION = '0.293';
+our $VERSION = '0.294';
 
 sub new {
     my $class = shift;
@@ -18,19 +18,21 @@ sub resolve {
     my ($self, $job) = @_;
     # here job = { package => "Plack", version_range => ">= 1.000, < 1.0030" }
 
+    my @error;
     for my $backend (@{ $self->{backends} }) {
         my $result = $backend->resolve($job);
-        if ($result) {
-            my $klass = ref $backend;
-            if ($klass =~ /^App::cpm::Resolver::(.*)$/) {
-                $result->{from} = $1;
-            } else {
-                $result->{from} = $klass;
-            }
+        next unless $result;
+
+        my $klass = ref $backend;
+        $klass = $1 if $klass =~ /^App::cpm::Resolver::(.*)$/;
+        if (my $error = $result->{error}) {
+            push @error, "$klass, $error";
+        } else {
+            $result->{from} = $klass;
             return $result;
         }
     }
-    return;
+    return { error => join("\n", @error) };
 }
 
 1;
