@@ -2,7 +2,7 @@ package App::cpm::Resolver::MetaCPAN;
 use strict;
 use warnings;
 use JSON::PP ();
-our $VERSION = '0.293';
+our $VERSION = '0.294';
 
 my $HTTP_CLIENT_CLASS = do {
     if (eval { require IO::Socket::SSL }) {
@@ -31,7 +31,7 @@ sub _encode {
 sub resolve {
     my ($self, $job) = @_;
     if ($self->{only_dev} and !$job->{dev}) {
-        return;
+        return { error => "skip, because MetaCPAN is configured to resolve dev releases only" };
     }
 
     my %query = (
@@ -43,9 +43,13 @@ sub resolve {
     my $res;
     for (1..2) {
         $res = $self->{http}->get($uri);
-        last if $res->{success} or !($res->{status} == 599 and $res->{content} =~ /timed out/);
+        last if $res->{success} or $res->{status} == 404;
+    }
+    if (!$res->{success}) {
+        my $error = "$res->{status} $res->{reason}, $uri";
+        $error .= ", $res->{content}" if $res->{status} == 599;
+        return { error => $error };
     }
-    return unless $res->{success};
 
     my $hash = eval { JSON::PP::decode_json($res->{content}) } or return;
     my ($distfile) = $hash->{download_url} =~ m{/authors/id/(.+)};
@@ -53,7 +57,7 @@ sub resolve {
         source => "cpan", # XXX
         distfile => $distfile,
         package => $job->{package},
-        version => $hash->{version},
+        version => $hash->{version} || 0,
         uri => $hash->{download_url},
     };
 }
