@@ -2,7 +2,7 @@ package App::cpm::Resolver::MetaDB;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.293';
+our $VERSION = '0.294';
 
 use HTTP::Tiny;
 use CPAN::Meta::YAML;
@@ -23,12 +23,31 @@ sub new {
     }, $class;
 }
 
+sub _get {
+    my ($self, $uri) = @_;
+    my $res;
+    for (1..2) {
+        $res = $self->{http}->get($uri);
+        last if $res->{success} or $res->{status} == 404;
+    }
+    $res;
+}
+
+sub _uniq {
+    my %x; grep { !$x{$_ || ""}++ } @_;
+}
+
 sub resolve {
     my ($self, $job) = @_;
 
     if (defined $job->{version_range} and $job->{version_range} =~ /(?:<|!=|==)/) {
-        my $res = $self->{http}->get( "$self->{uri}history/$job->{package}" );
-        return unless $res->{success};
+        my $uri = "$self->{uri}history/$job->{package}";
+        my $res = $self->_get($uri);
+        if (!$res->{success}) {
+            my $error = "$res->{status} $res->{reason}, $uri";
+            $error .= ", $res->{content}" if $res->{status} == 599;
+            return { error => $error };
+        }
 
         my @found;
         for my $line ( split /\r?\n/, $res->{content} ) {
@@ -41,7 +60,6 @@ sub resolve {
             }
         }
 
-        return unless @found;
         $found[-1]->{latest} = 1;
 
         my $match;
@@ -60,15 +78,22 @@ sub resolve {
                 uri     => [map { "${_}authors/id/$distfile" } @{$self->{mirror}}],
                 distfile => $distfile,
             };
+        } else {
+            return { error => "found versions @{[join ',', _uniq map $_->{version}, @found]}, but they do not satisfy $job->{version_range}, $uri" };
         }
     } else {
-        my $res = $self->{http}->get( "$self->{uri}package/$job->{package}" );
-        return unless $res->{success};
+        my $uri = "$self->{uri}package/$job->{package}";
+        my $res = $self->_get($uri);
+        if (!$res->{success}) {
+            my $error = "$res->{status} $res->{reason}, $uri";
+            $error .= ", $res->{content}" if $res->{status} == 599;
+            return { error => $error };
+        }
 
         my $yaml = CPAN::Meta::YAML->read_string($res->{content});
         my $meta = $yaml->[0];
         if (!App::cpm::version->parse($meta->{version})->satisfy($job->{version_range})) {
-            return;
+            return { error => "found version $meta->{version}, but it does not satisfy $job->{version_range}, $uri" };
         }
         my @provides = map {
             my $package = $_;
