@@ -4,7 +4,7 @@ use warnings;
 use App::cpm::version;
 use App::cpm::Logger;
 use Carton::Snapshot;
-our $VERSION = '0.293';
+our $VERSION = '0.294';
 
 sub new {
     my ($class, %option) = @_;
@@ -25,19 +25,20 @@ sub resolve {
     my ($self, $job) = @_;
     my $package = $job->{package};
     my $found = $self->snapshot->find($package);
-    return unless $found;
+    if (!$found) {
+        return { error => "not found, @{[$self->snapshot->path]}" };
+    }
 
     my $version = $found->version_for($package);
     if (my $version_range = $job->{version_range}) {
         if (!App::cpm::version->parse($version)->satisfy($version_range)) {
-            return;
+            return { error => "found version $version, but it does not satisfy $version_range, @{[$self->snapshot->path]}" };
         }
     }
 
     my @provides = map {
         my $package = $_;
         my $version = $found->provides->{$_}{version};
-        $version = undef if $version eq "undef";
         +{ package => $package, version => $version };
     } sort keys %{$found->provides};
 
@@ -46,7 +47,7 @@ sub resolve {
         source => "cpan",
         distfile => $distfile,
         uri => [map { "${_}authors/id/$distfile" } @{$self->{mirror}}],
-        version  => $version,
+        version  => $version || 0,
         provides => \@provides,
     };
 }
