@@ -1,17 +1,12 @@
 package App::cpm::Worker::Resolver;
 use strict;
 use warnings;
-our $VERSION = '0.293';
-use File::Temp ();
+our $VERSION = '0.294';
 use App::cpm::Logger::File;
 
 sub new {
     my ($class, %option) = @_;
-    my $logger = $option{logger};
-    if (!$logger) {
-        (undef, my $file) = File::Temp::tempfile(UNLINK => 1);
-        $logger = App::cpm::Logger::File->new($file);
-    }
+    my $logger = $option{logger} || App::cpm::Logger::File->new;
     bless { impl => $option{impl}, logger => $logger }, $class;
 }
 
@@ -19,16 +14,17 @@ sub work {
     my ($self, $job) = @_;
 
     local $self->{logger}->{context} = $job->{package};
-    if (my $result = $self->{impl}->resolve($job)) {
+    my $result = $self->{impl}->resolve($job);
+    if ($result and !$result->{error}) {
         $result->{ok} = 1;
         $result->{uri} = [$result->{uri}] unless ref $result->{uri};
-        my $msg = sprintf "Resolved %s (%s) -> %s", $job->{package}, $job->{version} || 0,
+        my $msg = sprintf "Resolved %s (%s) -> %s", $job->{package}, $job->{version_range} || 0,
             $result->{uri}[0] . ($result->{from} ? " from $result->{from}" : "");
         $self->{logger}->log($msg);
         return $result;
     } else {
-        my $msg = sprintf "Failed to resolve %s", $job->{package};
-        $self->{logger}->log($msg);
+        $self->{logger}->log($result->{error}) if $result and $result->{error};
+        $self->{logger}->log(sprintf "Failed to resolve %s", $job->{package});
         return { ok => 0 };
     }
 }
