@@ -2,7 +2,7 @@ package App::cpm::version;
 use strict;
 use warnings;
 use CPAN::Meta::Requirements;
-our $VERSION = '0.293';
+our $VERSION = '0.294';
 
 use parent 'version';
 
@@ -17,4 +17,13 @@ sub satisfy {
     $requirements->accepts_module('DummyModule', $self->numify);
 }
 
+# suppress warnings
+# > perl -Mwarnings -Mversion -e 'print version->parse("1.02_03")->numify'
+# alpha->numify() is lossy at -e line 1.
+# 1.020300
+sub numify {
+    no warnings;
+    shift->SUPER::numify(@_);
+}
+
 1;
